Exhaust fans
============

.. autoclass:: aioafero.v1.controllers.exhaust_fan.ExhaustFanController
   :members:
   :show-inheritance:
   :inherited-members: get_device, subscribe, items
   :no-index:
